#!/usr/bin/env python
# encoding: utf-8

# String used when printing a RunResult
run_string = """RunResult
command:\n{}
path:\n{}
stdout:\n{}
stderr:\n{}
returncode:\n{}
time:\n{}
env:\n{}"""


class RunResult:
    """Stores the results from running a command
    Attributes:
    :command: The command that was executed
    :path: Path where the command was executed
    :stdout: The standard output stream generated by the command
    :stderr: The standard error stream generated by the command
    :returncode: The return code set after invoking the command
    :time: The time it took to execute the command
    """

    def __init__(self, command, path, stdout, stderr, returncode, time, env):
        """Create a new RunResult object"""

        self.command = command
        self.path = path
        self.stdout = stdout
        self.stderr = stderr
        self.returncode = returncode
        self.time = time
        self.env = env

    def __str__(self):
        """Print the RunResult object as a string"""
        return run_string.format(
            self.command,
            self.path,
            self.stdout,
            self.stderr,
            self.returncode,
            self.time,
            self.env,
        )
